Remove the garbage files

This commit is contained in:
Anas Elgarhy 2022-10-27 17:57:09 +02:00
parent b1e403689f
commit c3cc2c4567
3 changed files with 0 additions and 2811 deletions

View File

@ -1,68 +0,0 @@
/* See LICENSE file for copyright and license details. */
/* def */
#define WEBBROWSER "google-chrome-stable"
#define TERMINAL "alacritty"
#define SCREENSHOT "spectacle"
#define GUI_FILEMANAGER "pcmanfm"
/* appearance */
static const unsigned int borderpx = 1; /* border pixel of windows */
static const unsigned int gappx = 3; /* gaps size between windows */
static const unsigned int snap = 32; /* snap pixel */
static const unsigned int systraypinning = 0; /* 0: sloppy systray follows selected monitor, >0: pin systray to monitor X */
static const unsigned int systrayonleft = 0; /* 0: systray in the right corner, >0: systray on left of status text */
static const unsigned int systrayspacing = 2; /* systray spacing */
static const int systraypinningfailfirst = 1; /* 1: if pinning fails, display systray on the first monitor, False: display systray on the last monitor*/
static const int showsystray = 1; /* 0 means no systray */
static const int showbar = 1; /* 0 means no bar */
static const int topbar = 1; /* 0 means bottom bar */
static const char *fonts[] = { "monospace:size=11", "Noto Color Emoji:size=11", "Nerd Font Mono:weight=bold:size=15:antialias=true:hinting=true" };
static const char dmenufont[] = "monospace:size=11";
static const char col_1[] = "#282c34"; // Background color of bar
static const char col_2[] = "#282c34"; // Background color of unfocused windows border
static const char col_3[] = "#d7d7d7";
static const char col_4[] = "#018858"; // Background color of focused windows border and tags (main color acent)
static const char *colors[][3] = {
/* fg bg border */
[SchemeNorm] = { col_3, col_1, col_2 },
[SchemeSel] = { col_3, col_4, col_4 },
};
// Autostart programs
static const char *const autostart[] = {
// Start my build of slstatus
"slstatus", NULL,
// Keyboard layouts switch (requires setxkbmap)
"setxkbmap", "-model", "pc101", "-layout", "us,ar", "-variant", ",,", "-option", "grp:win_space_toggle", NULL,
// "xkbset", "exp", "=sticky", "-twokey", "-latchlock", NULL, // sticky keys
"/bin/stickykeys", NULL, // sticky keys script
"picom", NULL, // Start compositor , for transparency
"nitrogen", "--restore", NULL, // Restores the wallpaper
"nm-applet", NULL, // Start the network manger
"copyq", NULL, // clipboard manger
NULL /* terminate */
};
/* tagging */
// static const char *tags[] = { "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX" };
static const char *tags[] = { "", "", "", "", "", "", "", "", "" };
static const Rule rules[] = {
/* xprop(1):
* WM_CLASS(STRING) = instance, class
* WM_NAME(STRING) = title
*/
/* class instance title tags mask isfloating monitor */
{ "Gimp", NULL, NULL, 0, 1, -1 },
{ WEBBROWSER, NULL, NULL, 1 << 8, 0, -1 },
};
/* layout(s) */
static const float mfact = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster = 1; /* number of clients in master area */
static const int resizehints = 1; /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */
#include "layouts/layouts.h"
#include "movestack.c"
#include "keys/keys.h"

View File

@ -1,96 +0,0 @@
--- config.def.h
+++ config.def.h
@@ -45,11 +45,11 @@ static const Layout layouts[] = {
/* key definitions */
#define MODKEY Mod1Mask
-#define TAGKEYS(KEY,TAG) \
- { MODKEY, KEY, view, {.ui = 1 << TAG} }, \
- { MODKEY|ControlMask, KEY, toggleview, {.ui = 1 << TAG} }, \
- { MODKEY|ShiftMask, KEY, tag, {.ui = 1 << TAG} }, \
- { MODKEY|ControlMask|ShiftMask, KEY, toggletag, {.ui = 1 << TAG} },
+#define TAGKEYS(CHAIN,KEY,TAG) \
+ { MODKEY, CHAIN, KEY, view, {.ui = 1 << TAG} }, \
+ { MODKEY|ControlMask, CHAIN, KEY, toggleview, {.ui = 1 << TAG} }, \
+ { MODKEY|ShiftMask, CHAIN, KEY, tag, {.ui = 1 << TAG} }, \
+ { MODKEY|ControlMask|ShiftMask, CHAIN, KEY, toggletag, {.ui = 1 << TAG} },
/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }
@@ -60,40 +60,42 @@ static const char *dmenucmd[] = { "dmenu_run", "-m", dmenumon, "-fn", dmenufont,
static const char *termcmd[] = { "st", NULL };
static Key keys[] = {
- /* modifier key function argument */
- { MODKEY, XK_p, spawn, {.v = dmenucmd } },
- { MODKEY|ShiftMask, XK_Return, spawn, {.v = termcmd } },
- { MODKEY, XK_b, togglebar, {0} },
- { MODKEY, XK_j, focusstack, {.i = +1 } },
- { MODKEY, XK_k, focusstack, {.i = -1 } },
- { MODKEY, XK_i, incnmaster, {.i = +1 } },
- { MODKEY, XK_d, incnmaster, {.i = -1 } },
- { MODKEY, XK_h, setmfact, {.f = -0.05} },
- { MODKEY, XK_l, setmfact, {.f = +0.05} },
- { MODKEY, XK_Return, zoom, {0} },
- { MODKEY, XK_Tab, view, {0} },
- { MODKEY|ShiftMask, XK_c, killclient, {0} },
- { MODKEY, XK_t, setlayout, {.v = &layouts[0]} },
- { MODKEY, XK_f, setlayout, {.v = &layouts[1]} },
- { MODKEY, XK_m, setlayout, {.v = &layouts[2]} },
- { MODKEY, XK_space, setlayout, {0} },
- { MODKEY|ShiftMask, XK_space, togglefloating, {0} },
- { MODKEY, XK_0, view, {.ui = ~0 } },
- { MODKEY|ShiftMask, XK_0, tag, {.ui = ~0 } },
- { MODKEY, XK_comma, focusmon, {.i = -1 } },
- { MODKEY, XK_period, focusmon, {.i = +1 } },
- { MODKEY|ShiftMask, XK_comma, tagmon, {.i = -1 } },
- { MODKEY|ShiftMask, XK_period, tagmon, {.i = +1 } },
- TAGKEYS( XK_1, 0)
- TAGKEYS( XK_2, 1)
- TAGKEYS( XK_3, 2)
- TAGKEYS( XK_4, 3)
- TAGKEYS( XK_5, 4)
- TAGKEYS( XK_6, 5)
- TAGKEYS( XK_7, 6)
- TAGKEYS( XK_8, 7)
- TAGKEYS( XK_9, 8)
- { MODKEY|ShiftMask, XK_q, quit, {0} },
+ /* modifier chain key key function argument */
+ { MODKEY, -1, XK_p, spawn, {.v = dmenucmd } },
+ { MODKEY|ShiftMask, -1, XK_Return, spawn, {.v = termcmd } },
+ { MODKEY, -1, XK_b, togglebar, {0} },
+ { MODKEY, -1, XK_j, focusstack, {.i = +1 } },
+ { MODKEY, -1, XK_k, focusstack, {.i = -1 } },
+ { MODKEY, -1, XK_i, incnmaster, {.i = +1 } },
+ { MODKEY, -1, XK_d, incnmaster, {.i = -1 } },
+ { MODKEY, -1, XK_h, setmfact, {.f = -0.05} },
+ { MODKEY, -1, XK_l, setmfact, {.f = +0.05} },
+ { MODKEY, -1, XK_Return, zoom, {0} },
+ { MODKEY, -1, XK_Tab, view, {0} },
+ { MODKEY|ShiftMask, -1, XK_c, killclient, {0} },
+ { MODKEY, -1, XK_t, setlayout, {.v = &layouts[0]} },
+ { MODKEY, -1, XK_f, setlayout, {.v = &layouts[1]} },
+ { MODKEY, -1, XK_m, setlayout, {.v = &layouts[2]} },
+ { MODKEY, -1, XK_space, setlayout, {0} },
+ { MODKEY|ShiftMask, -1, XK_space, togglefloating, {0} },
+ { MODKEY, -1, XK_0, view, {.ui = ~0 } },
+ { MODKEY|ShiftMask, -1, XK_0, tag, {.ui = ~0 } },
+ { MODKEY, -1, XK_comma, focusmon, {.i = -1 } },
+ { MODKEY, -1, XK_period, focusmon, {.i = +1 } },
+ { MODKEY|ShiftMask, -1, XK_comma, tagmon, {.i = -1 } },
+ { MODKEY|ShiftMask, -1, XK_period, tagmon, {.i = +1 } },
+ TAGKEYS( -1, XK_1, 0)
+ TAGKEYS( -1, XK_2, 1)
+ TAGKEYS( -1, XK_3, 2)
+ TAGKEYS( -1, XK_4, 3)
+ TAGKEYS( -1, XK_5, 4)
+ TAGKEYS( -1, XK_6, 5)
+ TAGKEYS( -1, XK_7, 6)
+ TAGKEYS( -1, XK_8, 7)
+ TAGKEYS( -1, XK_9, 8)
+ { MODKEY|ShiftMask, -1, XK_q, quit, {0} },
+ { MODKEY, XK_a, XK_d, spawn, {.v = dmenucmd } },
+ { MODKEY, XK_a, XK_t, spawn, {.v = termcmd } },
};
/* button definitions */

File diff suppressed because it is too large Load Diff